DataLad patches
***************

.. currentmodule:: datalad_next.patches
.. autosummary::
   :toctree: generated

   annexrepo
   common_cfg
   configuration
   create_sibling_ghlike
   customremotes_main
   distribution_dataset
   interface_utils
   push_optimize
   push_to_export_remote
   test_keyring
   siblings
